package com.ynet.life.security.key;

import java.io.FileInputStream;
import java.io.IOException;
import java.security.KeyManagementException;
import java.security.KeyStore;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.PrivateKey;
import java.security.PublicKey;
import java.security.UnrecoverableKeyException;
import java.security.cert.CertificateException;
import java.util.Enumeration;

/* loaded from: com_ynet_life_security_key.jar:com/ynet/life/security/key/KeysStore.class */
public class KeysStore {
    private static KeyStore keyStore;
    private static KeysStoreParams storeParams;

    private KeysStore() {
    }

    public static void init(KeysStoreParams params) throws NoSuchAlgorithmException, IOException, CertificateException, KeyStoreException, UnrecoverableKeyException, KeyManagementException {
        storeParams = params;
    }

    public static PublicKey getPublicKey(String alias) throws KeyStoreException, IOException, NoSuchAlgorithmException, CertificateException {
        getKeyStore();
        return keyStore.getCertificate(alias).getPublicKey();
    }

    public static PrivateKey getPrivateKey(String alias) throws KeyStoreException, IOException, NoSuchAlgorithmException, CertificateException, UnrecoverableKeyException {
        getKeyStore();
        return (PrivateKey) keyStore.getKey(alias, storeParams.getKeyStorePass());
    }

    private static KeyStore getKeyStore() throws KeyStoreException, IOException, NoSuchAlgorithmException, CertificateException {
        if (keyStore != null) {
            return keyStore;
        }
        FileInputStream in = null;
        try {
            try {
                String keystoreFile = storeParams.getKeyStoreFile();
                keyStore = KeyStore.getInstance(storeParams.getKeyStoreType());
                in = new FileInputStream(keystoreFile);
                keyStore.load(in, storeParams.getKeyStorePass());
                KeyStore keyStore2 = keyStore;
                in.close();
                return keyStore2;
            } catch (IOException ioe) {
                keyStore = null;
                throw ioe;
            }
        } catch (Throwable th) {
            in.close();
            throw th;
        }
    }

    /* JADX WARN: Type inference failed for: r0v7, types: [java.io.PrintStream, java.lang.Exception] */
    public static void main(String[] args) {
        ?? r0;
        try {
            init(new KeysStoreParams("E:/Life.jks", "123456"));
            Enumeration<String> e = getKeyStore().aliases();
            while (e.hasMoreElements()) {
                String als = e.nextElement();
                System.out.println("alias: ".concat(String.valueOf(als)));
            }
            System.out.println("\nmypairkey public key:\n" + getPublicKey("mypairkey"));
            r0 = System.out;
            r0.println("mypairkey private key:\n" + getPrivateKey("mypairkey"));
        } catch (Exception e2) {
            r0.printStackTrace();
        }
    }
}
